@@ -26,7 +26,7 @@ with
   },
   'Dist::Zilla::Role::PrereqSource';
 
-our $VERSION = 'v0.1.1';
+our $VERSION = 'v0.1.2';
 
 
 has filename => (
@@ -153,14 +153,21 @@ Dist::Zilla::Plugin::Test::MixedScripts - author tests to ensure there is no mix
 
 =head1 VERSION
 
-version v0.1.1
+version v0.1.2
 
 =head1 DESCRIPTION
 
 This generates an author L<Test::MixedScripts>.
 
 This is an extension of L<Dist::Zilla::Plugin::InlineFiles>, providing the file F<xt/author/mixed-unicode-scripts.t> for
-testing against mixed Unicode scripts.
+testing against mixed Unicode scripts that are potentially confusing or malicious.
+
+For example, the text for the domain names "E<0x043e>nE<0x0435>.example.com" and "one.example.com" look indistinguishable in many fonts,
+but the first one has Cyrillic letters.  If your software interacted with a service on the second domain, then someone
+can operate a service on the first domain and attempt to fool developers into using their domain instead.
+
+This might be through a malicious patch submission, or even text from an email or web page that they have convinced a
+developer to copy and paste into their code.
 
 =head1 CONFIGURATION OPTIONS
 
@@ -204,6 +211,15 @@ This specifies the scripts to test for.  If none are specified, it defaults to t
 
 =for Pod::Coverage register_prereqs
 
+=head1 KNOWN ISSUES
+
+The default L</finder> does not include XS-related files. You will have to add them manually using the L</file> option,
+for example, in the F<dist.ini>:
+
+    [Test::MixedScripts]
+    file = XS.xs
+    file = XS.c
+
 =head1 SOURCE
 
 The development version is on github at L<https://github.com/robrwo/perl-Dist-Zilla-Plugin-Test-MixedScripts>
